@@ -31,6 +31,8 @@
 #include <QSize>
 #include <QString>
 #include <cstring>
+#include "CroppedActiveLayerProxy.h"
+#include "CroppedImageListProxy.h"
 #include "FilterSyncRunner.h"
 #include "FilterThread.h"
 #include "Host/host.h"
@@ -68,16 +70,11 @@ void GmicProcessor::execute()
   gmic_list<char> imageNames;
   FilterContext::VisibleRect & rect = _filterContext.visibleRect;
   _gmicImages->assign();
-  gmic_qt_get_cropped_images(*_gmicImages, imageNames, rect.x, rect.y, rect.w, rect.h, _filterContext.inputOutputState.inputMode);
   if ((_filterContext.requestType == FilterContext::PreviewProcessing) || (_filterContext.requestType == FilterContext::SynchronousPreviewProcessing)) {
+    CroppedImageListProxy::get(*_gmicImages, imageNames, rect.x, rect.y, rect.w, rect.h, _filterContext.inputOutputState.inputMode, _filterContext.zoomFactor);
     updateImageNames(imageNames);
-    const double & zoomFactor = _filterContext.zoomFactor;
-    if (zoomFactor < 1.0) {
-      for (unsigned int i = 0; i < _gmicImages->size(); ++i) {
-        gmic_image<float> & image = (*_gmicImages)[i];
-        image.resize(std::round(image.width() * zoomFactor), std::round(image.height() * zoomFactor), 1, -100, 1);
-      }
-    }
+  } else {
+    CroppedImageListProxy::get(*_gmicImages, imageNames, rect.x, rect.y, rect.w, rect.h, _filterContext.inputOutputState.inputMode, 1.0);
   }
   _waitingCursorTimer.start(WAITING_CURSOR_DELAY);
   const GmicQt::InputOutputState & io = _filterContext.inputOutputState;
@@ -259,6 +256,9 @@ void GmicProcessor::onApplyThreadFinished()
     _filterThread = nullptr;
     emit fullImageProcessingFailed(message);
   } else {
+    if (GmicQt::HostApplicationName.isEmpty()) {
+      emit aboutToSendImagesToHost();
+    }
     _filterThread->swapImages(*_gmicImages);
     if (_filterContext.outputMessageMode == GmicQt::VerboseLayerName) {
       QString label = QString("[G'MIC] %1: %2").arg(_filterThread->name()).arg(_filterThread->fullCommand());
@@ -266,6 +266,9 @@ void GmicProcessor::onApplyThreadFinished()
     } else {
       gmic_qt_output_images(*_gmicImages, _filterThread->imageNames(), _filterContext.inputOutputState.outputMode, 0);
     }
+    LayersExtentProxy::clear();
+    CroppedActiveLayerProxy::clear();
+    CroppedImageListProxy::clear();
     _filterThread->deleteLater();
     _filterThread = nullptr;
     _lastAppliedCommandGmicStatus = _gmicStatus;
@@ -275,7 +278,6 @@ void GmicProcessor::onApplyThreadFinished()
 
 void GmicProcessor::onAbortedThreadFinished()
 {
-  // TSHOW(_unfinishedAbortedThreads.size());
   FilterThread * thread = dynamic_cast<FilterThread *>(sender());
   if (_unfinishedAbortedThreads.contains(thread)) {
     _unfinishedAbortedThreads.removeOne(thread);
