@@ -91,8 +91,6 @@ public slots:
   void onToggleFullScreen(bool on);
   void onSettingsClicked();
   void onStartupFiltersUpdateFinished(int);
-  void onZoomIn();
-  void onZoomOut();
   void showZoomWarningIfNeeded();
   void updateZoomLabel(double);
   void onFiltersSelectionModeToggled(bool);
@@ -125,6 +123,7 @@ private slots:
   void onInputModeChanged(GmicQt::InputMode);
 
 private:
+  void setZoomConstraint();
   bool filtersSelectionMode();
   void clearMessage();
   void showMessage(QString text, int ms = 2000);
